Class: Google::Apis::SearchconsoleV1::RunMobileFriendlyTestResponse

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/searchconsole_v1/classes.rb,
lib/google/apis/searchconsole_v1/representations.rb,
lib/google/apis/searchconsole_v1/representations.rb

Overview

Mobile-friendly test response, including mobile-friendly issues and resource issues.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ RunMobileFriendlyTestResponse

Returns a new instance of RunMobileFriendlyTestResponse.



710
711
712
# File 'lib/google/apis/searchconsole_v1/classes.rb', line 710

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#mobile_friendlinessString

Test verdict, whether the page is mobile friendly or not. Corresponds to the JSON property mobileFriendliness

Returns:

  • (String)


688
689
690
# File 'lib/google/apis/searchconsole_v1/classes.rb', line 688

def mobile_friendliness
  @mobile_friendliness
end

#mobile_friendly_issuesArray<Google::Apis::SearchconsoleV1::MobileFriendlyIssue>

List of mobile-usability issues. Corresponds to the JSON property mobileFriendlyIssues



693
694
695
# File 'lib/google/apis/searchconsole_v1/classes.rb', line 693

def mobile_friendly_issues
  @mobile_friendly_issues
end

#resource_issuesArray<Google::Apis::SearchconsoleV1::ResourceIssue>

Information about embedded resources issues. Corresponds to the JSON property resourceIssues



698
699
700
# File 'lib/google/apis/searchconsole_v1/classes.rb', line 698

def resource_issues
  @resource_issues
end

#screenshotGoogle::Apis::SearchconsoleV1::Image

Describe image data. Corresponds to the JSON property screenshot



703
704
705
# File 'lib/google/apis/searchconsole_v1/classes.rb', line 703

def screenshot
  @screenshot
end

#test_statusGoogle::Apis::SearchconsoleV1::TestStatus

Final state of the test, including error details if necessary. Corresponds to the JSON property testStatus



708
709
710
# File 'lib/google/apis/searchconsole_v1/classes.rb', line 708

def test_status
  @test_status
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



715
716
717
718
719
720
721
# File 'lib/google/apis/searchconsole_v1/classes.rb', line 715

def update!(**args)
  @mobile_friendliness = args[:mobile_friendliness] if args.key?(:mobile_friendliness)
  @mobile_friendly_issues = args[:mobile_friendly_issues] if args.key?(:mobile_friendly_issues)
  @resource_issues = args[:resource_issues] if args.key?(:resource_issues)
  @screenshot = args[:screenshot] if args.key?(:screenshot)
  @test_status = args[:test_status] if args.key?(:test_status)
end