Class: Google::Apis::SearchconsoleV1::RichResultsInspectionResult
- Inherits:
-
Object
- Object
- Google::Apis::SearchconsoleV1::RichResultsInspectionResult
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/searchconsole_v1/classes.rb,
lib/google/apis/searchconsole_v1/representations.rb,
lib/google/apis/searchconsole_v1/representations.rb
Overview
Rich-Results inspection result, including any rich results found at this URL.
Instance Attribute Summary collapse
-
#detected_items ⇒ Array<Google::Apis::SearchconsoleV1::DetectedItems>
A list of zero or more rich results detected on this page.
-
#verdict ⇒ String
High-level rich results inspection result for this URL.
Instance Method Summary collapse
-
#initialize(**args) ⇒ RichResultsInspectionResult
constructor
A new instance of RichResultsInspectionResult.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ RichResultsInspectionResult
Returns a new instance of RichResultsInspectionResult.
616 617 618 |
# File 'lib/google/apis/searchconsole_v1/classes.rb', line 616 def initialize(**args) update!(**args) end |
Instance Attribute Details
#detected_items ⇒ Array<Google::Apis::SearchconsoleV1::DetectedItems>
A list of zero or more rich results detected on this page. Rich results that
cannot even be parsed due to syntactic issues will not be listed here.
Corresponds to the JSON property detectedItems
609 610 611 |
# File 'lib/google/apis/searchconsole_v1/classes.rb', line 609 def detected_items @detected_items end |
#verdict ⇒ String
High-level rich results inspection result for this URL.
Corresponds to the JSON property verdict
614 615 616 |
# File 'lib/google/apis/searchconsole_v1/classes.rb', line 614 def verdict @verdict end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
621 622 623 624 |
# File 'lib/google/apis/searchconsole_v1/classes.rb', line 621 def update!(**args) @detected_items = args[:detected_items] if args.key?(:detected_items) @verdict = args[:verdict] if args.key?(:verdict) end |